pub type AttrObj = Box<dyn Attribute>;Expand description
Attribute objects are boxed and stored in the IR.
Aliased Type
pub struct AttrObj(/* private fields */);Trait Implementations
Sourceimpl Parsable for AttrObj
impl Parsable for AttrObj
Sourcefn parse<'a>(
state_stream: &mut StateStream<'a>,
_arg: Self::Arg,
) -> ParseResult<'a, Self::Parsed>
fn parse<'a>( state_stream: &mut StateStream<'a>, _arg: Self::Arg, ) -> ParseResult<'a, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<StateStream<'a>, Output = Self::Parsed, PartialState = ()> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<StateStream<'a>, Output = Self::Parsed, PartialState = ()> + 'a>
Get a parser combinator that can work on StateStream as its input.